@@ -33,9 +33,10 @@
 #  define KWALLET_DEPRECATED_NO_EXPORT KWALLET_NO_EXPORT KWALLET_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KWALLET_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KWALLET_NO_DEPRECATED
+#    define KWALLET_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
